pub struct RKF78 {
pub tol: f64,
pub safety_factor: f64,
pub min_step_size: f64,
pub max_step_size: f64,
pub max_step_iter: usize,
}Expand description
Runge-Kutta-Fehlberg 7/8th order integrator.
This integrator uses the Runge-Kutta-Fehlberg 7(8) method, an adaptive step size integrator. It evaluates f(x,y) thirteen times per step, using embedded 7th and 8th order Runge-Kutta estimates to estimate the solution and the error. The 7th order solution is propagated, and the difference between the 8th and 7th order solutions is used for error estimation and step size control.
Member variables
tol: The tolerance for the estimated error.safety_factor: The safety factor for the step size adjustment.min_step_size: The minimum step size.max_step_size: The maximum step size.max_step_iter: The maximum number of iterations per step.
References
- Meysam Mahooti (2025). Runge-Kutta-Fehlberg (RKF78), MATLAB Central File Exchange.
Fields
tol: f64safety_factor: f64min_step_size: f64max_step_size: f64max_step_iter: usizeImplementations